@@ -326,7 +326,8 @@ class AwsAccount:
                 open_days_counter[finding.days_open] += 1
         if not counted_findings:
             self._logger.info(f'No findings for account {self.id}')
-            return AccountEnergyLabel('A', 0, 0, 0, 0)
+            self.energy_label = AccountEnergyLabel('A', 0, 0, 0, 0)
+            return self.energy_label
         try:
             number_of_critical_findings = counted_findings.get('CRITICAL', 0)
             number_of_high_findings = counted_findings.get('HIGH', 0)
@@ -514,11 +515,15 @@ class Finding:  # pylint: disable=too-many-public-methods
     @property
     def first_observed_at(self):
         """First observed at."""
+        if self._data.get('FirstObservedAt') is None:
+            return self._parse_date_time(self._data.get('CreatedAt'))
         return self._parse_date_time(self._data.get('FirstObservedAt'))
 
     @property
     def last_observed_at(self):
         """Last observed at."""
+        if self._data.get('LastObservedAt') is None:
+            return self._parse_date_time(self._data.get('UpdatedAt'))
         return self._parse_date_time(self._data.get('LastObservedAt'))
 
     @property
